import{j as e}from"./vendor-motion-k_x_E260.js";import{h as i,L as l,B as n,C as d,T as o,c as m}from"./index-BSlTCSQu.js";import"./vendor-icons-BDy0XSiX.js";import"./vendor-react-BaJ9Uc06.js";function j(){const t=i();if(t._loading)return e.jsx(l,{label:"Loading leaderboard…"});const s=t.top;return e.jsxs("div",{className:"space-y-6",children:[e.jsxs("div",{className:"flex items-center justify-between",children:[e.jsx("h2",{className:"text-lg font-bold",children:"Leaderboard"}),e.jsxs(n,{color:"purple",children:[s.length," entries"]})]}),e.jsx(d,{children:e.jsx(o,{columns:[{key:"rank",label:"#",w:"40px"},{key:"idea_id",label:"Idea"},{key:"title",label:"Title"},{key:"metric",label:t.metric||"Metric"},{key:"time",label:"Training Time"}],rows:s.map((a,r)=>({rank:e.jsx("span",{className:r<3?"text-amber-400 font-bold":"",children:r+1}),idea_id:e.jsx("span",{className:"font-mono text-xs",children:a.idea_id}),title:e.jsx("span",{className:"text-xs text-gray-400 truncate block max-w-[300px]",children:a.title||"-"}),metric:e.jsx("span",{className:"font-mono text-emerald-400",children:typeof a.metric_value=="number"?a.metric_value.toFixed(4):"-"}),time:e.jsx("span",{className:"text-xs text-gray-500",children:a.training_time?m(a.training_time/60):"-"})}))})})]})}export{j as default};
